@@ -1,5 +1,8 @@
-/*  libticables - link cable library, a part of the TiLP project
- *  Copyright (C) 1999-2002  Romain Lievin
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: cabl_ver.h 651 2004-04-25 15:22:07Z roms $ */
+
+/*  libticables - Ti Link Cable library, a part of the TiLP project
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,13 +27,9 @@
 #endif
 
 #ifdef __WIN32__
-# define LIBTICABLES_VERSION "3.2.3"
+# define LIBTICABLES_VERSION "3.8.4"
 #else
-# ifndef VERSION
-#  define LIBTICABLES_VERSION VERSION
-# else
-#  define LIBTICABLES_VERSION "9.9.9"
-#endif
+# define LIBTICABLES_VERSION VERSION
 #endif
 
 #endif
