@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: intrface.c 651 2004-04-25 15:22:07Z roms $ */
+/* $Id: intrface.c 751 2004-06-17 10:04:25Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -27,7 +27,7 @@
 #include <windows.h>
 #endif
 
-#include "intl1.h"
+#include "gettext.h"
 
 #include "cabl_ver.h"
 #include "cabl_def.h"
@@ -46,11 +46,7 @@ int time_out = DFLT_TIMEOUT; // Timeout value for cables in 0.10 seconds
 int delay = DFLT_DELAY;      // Time between 2 bits (home-made cables only)
 int baud_rate = BR9600;      // Baud rate setting for serial port
 int hfc = HFC_ON;            // Hardware flow control for fastAVRlink
-#ifdef __MACOSX__
-int port = OSX_USB_PORT;     // Use USB by default, handled through the IOKit
-#else
-int port = SERIAL_PORT_2;    // Use COM2 by default
-#endif
+int port = NULL_PORT;        // No port and null cable
 int resources = IO_NONE;     // I/O resources detected
 TicableMethod method = IOM_AUTO;      // I/O methods useable
 
@@ -77,22 +73,26 @@ int ticables_instance = 0;	// counts # of instances
 TIEXPORT int
 TICALL ticable_init()
 {
+	char locale_dir[65536];
+	
 #ifdef __WIN32__
   	HANDLE hDll;
-  	char LOCALEDIR[65536];
   	int i;
   	
   	hDll = GetModuleHandle("ticables.dll");
-  	GetModuleFileName(hDll, LOCALEDIR, 65535);
+  	GetModuleFileName(hDll, locale_dir, 65535);
   	
-  	for (i = strlen(LOCALEDIR); i >= 0; i--) {
-    	if (LOCALEDIR[i] == '\\')
+  	for (i = strlen(locale_dir); i >= 0; i--) {
+    	if (locale_dir[i] == '\\')
       		break;
   	}
   	
-  	LOCALEDIR[i] = '\0';
-  	strcat(LOCALEDIR, "\\locale");
+  	locale_dir[i] = '\0';
+  	strcat(locale_dir, "\\locale");
+#else
+	strcpy(locale_dir, LOCALEDIR);
 #endif
+
 	if (ticables_instance)
 		return (++ticables_instance);
 	printl1(0, _("ticables library version %s\n"), LIBTICABLES_VERSION);
@@ -100,7 +100,7 @@ TICALL ticable_init()
 
 #if defined(ENABLE_NLS)
   	printl1(0, "setlocale: <%s>\n", setlocale(LC_ALL, ""));
-  	printl1(0, "bindtextdomain: <%s>\n", bindtextdomain(PACKAGE, LOCALEDIR));
+  	printl1(0, "bindtextdomain: <%s>\n", bindtextdomain(PACKAGE, locale_dir));
   	//bind_textdomain_codeset(PACKAGE, "UTF-8"/*"ISO-8859-15"*/);
   	printl1(0, "textdomain: <%s>\n", textdomain(PACKAGE));
 #endif
